summaryrefslogtreecommitdiff
path: root/source/compiler/aslerror.c
diff options
context:
space:
mode:
authorErik Schmauss <erik.schmauss@intel.com>2017-08-25 11:19:07 -0700
committerErik Schmauss <erik.schmauss@intel.com>2017-08-25 13:53:52 -0700
commit57c6d8ed4a26d48d328d1a129ffb8eb25dcb7743 (patch)
tree80519b4c76c461003cf9277e05de6fdd974e36cb /source/compiler/aslerror.c
parent78ed189ab6eae555bac5a11174a00130caed44ae (diff)
downloadacpica-57c6d8ed4a26d48d328d1a129ffb8eb25dcb7743.tar.gz
iASL: change -vw option to ignore errors in addition to warnings and remarks
Signed-off-by: Erik Schmauss <erik.schmauss@intel.com>
Diffstat (limited to 'source/compiler/aslerror.c')
-rw-r--r--source/compiler/aslerror.c7
1 files changed, 4 insertions, 3 deletions
diff --git a/source/compiler/aslerror.c b/source/compiler/aslerror.c
index ec91ca3e7..6f8ea88a8 100644
--- a/source/compiler/aslerror.c
+++ b/source/compiler/aslerror.c
@@ -949,9 +949,9 @@ AslDisableException (
MessageId = (UINT32) strtoul (MessageIdString, NULL, 0);
- if ((MessageId < 2000) || (MessageId > 5999))
+ if ((MessageId < 2000) || (MessageId > 6999))
{
- printf ("\"%s\" is not a valid warning/remark ID\n",
+ printf ("\"%s\" is not a valid warning/remark/error ID\n",
MessageIdString);
return (AE_BAD_PARAMETER);
}
@@ -1050,8 +1050,9 @@ AslIsExceptionDisabled (
case ASL_WARNING:
case ASL_REMARK:
+ case ASL_ERROR:
/*
* Ignore this warning/remark if it has been disabled by
* the user (-vw option)
*/
EncodedMessageId = AeBuildFullExceptionCode (Level, MessageId);
@@ -1050,8 +1050,9 @@ AslIsExceptionDisabled (
/*
- * Ignore this warning/remark if it has been disabled by
+ * Ignore this error/warning/remark if it has been disabled by
* the user (-vw option)
*/